/**
 * Copyright (C) 2015 Red Hat, Inc.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *         http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package io.fabric8.kubernetes.client.dsl.internal;

import io.fabric8.kubernetes.client.dsl.Resource;
import io.fabric8.kubernetes.client.dsl.base.OperationContext;
import okhttp3.OkHttpClient;
import io.fabric8.kubernetes.api.model.DoneablePersistentVolume;
import io.fabric8.kubernetes.api.model.PersistentVolume;
import io.fabric8.kubernetes.api.model.PersistentVolumeList;
import io.fabric8.kubernetes.client.Config;
import io.fabric8.kubernetes.client.dsl.base.HasMetadataOperation;

public class PersistentVolumeOperationsImpl
  extends HasMetadataOperation<PersistentVolume, PersistentVolumeList, DoneablePersistentVolume, Resource<PersistentVolume, DoneablePersistentVolume>> {

  public PersistentVolumeOperationsImpl(OkHttpClient client, Config config) {
    this(client, config, null);
  }

  public PersistentVolumeOperationsImpl(OkHttpClient client, Config config, String namespace) {
    this(new OperationContext().withOkhttpClient(client).withConfig(config).withNamespace(namespace));
  }

  public PersistentVolumeOperationsImpl(OperationContext context) {
    super(context.withPlural("persistentvolumes"));
    this.type = PersistentVolume.class;
    this.listType = PersistentVolumeList.class;
    this.doneableType = DoneablePersistentVolume.class;
  }

  @Override
  public PersistentVolumeOperationsImpl newInstance(OperationContext context) {
    return new PersistentVolumeOperationsImpl(context);
  }

  @Override
  public boolean isResourceNamespaced() {
      return false;
  }
}
